summaryrefslogtreecommitdiff
path: root/ace/Thread.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1996-11-17 00:40:23 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1996-11-17 00:40:23 +0000
commitcdaa50473d4305fca20da3227099dcb1de31c1b8 (patch)
treed3c48504214f87beeb823ccd977e8f0ca0f0bfe2 /ace/Thread.h
parent655565f17014c6ffa30fcd70764e28fad8149ebf (diff)
downloadATCD-cdaa50473d4305fca20da3227099dcb1de31c1b8.tar.gz
Help!
Diffstat (limited to 'ace/Thread.h')
-rw-r--r--ace/Thread.h19
1 files changed, 11 insertions, 8 deletions
diff --git a/ace/Thread.h b/ace/Thread.h
index 9258f4093e3..1579dc4e29f 100644
--- a/ace/Thread.h
+++ b/ace/Thread.h
@@ -63,17 +63,20 @@ public:
long flags,
u_int priority = 0,
void *stack[] = 0,
- size_t stack_size[] = 0);
+ size_t stack_size[] = 0,
+ ACE_hthread_t thread_handles[] = 0);
// Spawn N new threads, which execute <func> with argument <arg>.
// The thread_ids of successfully spawned threads will be placed
- // into the <thread_ids> buffer, which must be the same size as <n>.
- // If <stack> != 0 it is assumed to be an array of <n> pointers to
- // the base of the stacks to use for the threads being spawned.
- // Likewise, if <stack_size> != 0 it is assumed to be an array of
+ // into the <thread_ids> buffer (which must be the same size as
+ // <n>). If <stack> != 0 it is assumed to be an array of <n>
+ // pointers to the base of the stacks to use for the threads being
+ // spawned. If <stack_size> != 0 it is assumed to be an array of
// <n> values indicating how big each of the corresponding <stack>s
// are. Returns the number of threads actually spawned (if this
// doesn't equal the number requested then something has gone wrong
// and <errno> will explain...).
static int join (ACE_thread_t,
ACE_thread_t *,
@@ -63,17 +63,20 @@ public:
// <n> values indicating how big each of the corresponding <stack>s
- // are. Returns the number of threads actually spawned (if this
- // doesn't equal the number requested then something has gone wrong
- // and <errno> will explain...).
+ // are. If <thread_handles> != 0 it is assumed to be an array of
+ // <n> thread_handles that will be assigned the values of the thread
+ // handles being spawned. Returns the number of threads actually
+ // spawned (if this doesn't equal the number requested then
+ // something has gone wrong and <errno> will explain...).
static int join (ACE_thread_t,
ACE_thread_t *,